/*
 * BnetDiagTool.h
 * ==============
 * Copyright (C) Matthew J. W.
 * All rights reserved.
 * Version 1.0
 *
 *
 * Description:
 *   Master include file.
 *
 *
 *******************************************************************************************************************************************************/
#pragma once



//--------------------------------------------------------------------------
// Macros
//--------------------------------------------------------------------------
#define LOG_FILENAME             "Log.txt"
#define SERVER_PORT              57367
#define SERVER_RESPONSE_TIMEOUT  1500
#define MAXCMDLEN                50


//--------------------------------------------------------------------------
// Commands
//--------------------------------------------------------------------------
#define COMMAND_RESOLVE  "resolve"
#define COMMAND_CONNECT  "connect"
#define COMMAND_HELP     "?"
#define COMMAND_EXIT     "exit"


//--------------------------------------------------------------------------
// Messages
//--------------------------------------------------------------------------
#define MSG_NEWLINE            "\r\n"
#define MSG_PROMPT_PREFIX      "\nCommand> "
#define MSG_BAD_COMMAND        "\nInvalid command."
#define MSG_BAD_NUM_PARAMS     "\nIncorrect number of parameters for this command."
#define MSG_ERROR              "Error! "
#define MSG_ERROR_FAILED       "\r\nFailed to retrieve proper error code."
#define MSG_ERROR_BAD_CLEANUP  "\r\nAn error occured during error cleanup."
#define MSG_CRITICAL_ERROR     "CRITICAL ERROR:\nAn unrecoverable error has occured. Application must terminate."
#define MSG_YES                "Yes"
#define MSG_NO                 "No"
#define MSG_APPINIT            "+++ Begin application initialization."
#define MSG_INIT_CONSOLE       "\r\nInitializing console... "
#define MSG_INIT_CTRL_HANDLER  "\r\nAssigning console control handler... "
#define MSG_INIT_WINSOCK       "\r\nLoading the Winsock library... "
#define MSG_INIT_DONE          "\r\nInitialization complete."
#define MSG_EXIT               "\r\n\r\n+++ Exiting application."
#define MSG_WSCLEANUP_ERROR    "\r\nAn error occured while unloading the Winsock library."
#define MSG_APPLOG_CLOSE       "\r\nClosing the application log..."
#define MSG_CONNECT_START      "\r\n\r\n+++ Begin connection test with Battle.net server "
#define MSG_CONNECT_CREATE     "\r\nCreating socket... "
#define MSG_CONNECT_BIND       "\r\nBinding socket to any available address... "
#define MSG_CONNECT_ASYNC      "\r\nPlacing socket into asynchronous mode... "
#define MSG_CONNECT_INITIATE   "\r\nInitiating connection... "
#define MSG_CONNECT_BEGIN      "\r\nAttempting to establish a connection with the server... "
#define MSG_CONNECT_CONNECTED  "\r\nConnection established with the server, determining if user is banned... "
#define MSG_CONNECT_SHUTDOWN   "\r\nShutting down connection... "
#define MSG_CONNECT_CLOSE      "\r\nClosing connection... "
#define MSG_CONNECT_DONE       "\r\nConnection established!"
#define MSG_CONNECT_BANNED     "\r\nYou appear to be IP banned."
#define MSG_RESOLVE_START      "\r\n\r\n+++ Begin hostname resolution on "
#define MSG_RESOLVE_BEGIN      "\r\nQuerying information about the host... "
#define MSG_RESOLVE_SUCCEEDED  "\r\nHostname successfully resolved, displaying results..."


//--------------------------------------------------------------------------
// System Dependencies
//--------------------------------------------------------------------------
#include <winsock2.h> // Window's Sockets API.
#include <windows.h>  // Windows API.
#include <tlhelp32.h> // System information helper.
#include <ws2tcpip.h> // Winsock TCP/IP extensions.


//--------------------------------------------------------------------------
// Project Elements
//--------------------------------------------------------------------------
#include "Types.h"
#include "Utility.h"


//--------------------------------------------------------------------------
// Functions
//--------------------------------------------------------------------------
extern Bool __stdcall  Initialize();
extern Void __stdcall  Cleanup();
extern Bool __stdcall  OnConsoleCtrl(Dword dwCtrlType);
extern Bool __fastcall ProcessCommand();
extern Bool __fastcall Resolve(const Char* pstrHostname);
extern Bool __fastcall Connect(Dword dwServer);
extern Bool __stdcall  OpenConsole();
extern Void __fastcall ConsoleOut(const Char* pstr);
extern Void __fastcall ConsoleOutInt(Dword dwInt);
extern Void __fastcall ConsoleIn(Char* pstr, Dword dwCharacters);
extern Void __stdcall  CloseConsole();
extern Bool __fastcall OpenLog();
extern Void __fastcall WriteLog(const Char* pstr);
extern Void __fastcall WriteLog(const Char c);
extern Void __fastcall WriteLogInt(Dword dwInteger);
extern Void __stdcall  PrepareLog();
extern Void __stdcall  CloseLog();